@@ -27,14 +27,33 @@ class StatusCode:
     USER_NAME_VALIDATE_FAIL = ("A0110", "用户名校验失败")
     USER_NAME_EXIST = ("A0111", "用户名已存在")
     USER_NAME_INVALID = ("A0112", "用户名包含特殊字符")
-    PASSWORD_VALIDATE_FAIL = ("A0120", "密码校验失败")
+    PASSWORD_VALIDATE_FAIL = ("A0120", "密码错误")
     PASSWORD_LENGTH_VALID = ("A0121", "密码长度不够")
     SHORT_MESSAGE_VALID_FAIL = ("A0130", "短信验证码错误")
     VALIDATE_CODE_ERROR = ("A0131", "验证码错误！")
-    USER_LOGIN_EXCEPTION = ("A0200", "用户登陆异常")
-    USER_ACCOUNT_NOT_EXIST = ("A0201", "用户账户不存在")
+    USER_LOGIN_EXCEPTION = ("A0200", "用户登录异常")
+    USER_ACCOUNT_NOT_EXIST = ("A0201", "用户不存在")
+    USER_ACCOUNT_EXPIRE = ("A0202", "账号已失效，请联系管理员！")
+    USER_ACCOUNT_PASSWORD_EXPIRE = ("A0203", "密码已失效，请修改密码，重新登录")
+    USER_ACCOUNT_EXCEEDED_ERRORS = ("A0204", "密码错误次数过多，账号已锁定，请稍后重试")
+    USER_ACCOUNT_DORMANCY = ("A0205", "账号处于休眠状态，请联系管理员！")
+
     REQUEST_PARAM_ERROR = ("A0300", "用户请求参数错误")
     INVALID_USER_INPUT = ("A0301", "无效的用户输入")
+    Insecure_Transport_Error = ("A0303", "OAuth 2 必须使用 https.")
+    Invalid_Request_Error = ("A0303", "无效的请求")
+    Invalid_Client_Error = ("A0304", "无效客户端信息")
+    Invalid_Grant_Error = ("A0305", "无效授权类型")
+    Unauthorized_Client_Error = ("A0306", "未授权客户端信息")
+    Unsupported_GrantType_Error = ("A0306", "不支持的授权类型")
+    Invalid_Scope_Error = ("A0307", "请求的作用域无效、未知或格式不正确")
+    Access_Denied_Error = ("A0308", "请求被拒绝")
+    Missing_Authorization_Error = ("A0309", "请求headers中缺少 Authorization 参数")
+    Unsupported_Token_Type_Error = ("A0310", "不支持的token类型")
+    Missing_Code_Exception = ("A0311", '请求响应中缺少 "code"')
+    Missing_Token_Exception = ("A0312", '请求响应中缺少 "access_token"')
+    Missing_Token_Type_Exception = ("A0313", '请求响应中缺少 "token_type"')
+    Mismatching_State_Exception = ("A0314", "CSRF告警！请求和响应中的状态不相等")
 
     # REQUIRED_PARAM_IS_EMPTY = ("A0310", "请求缺少必要参数:{}")
     @staticmethod
@@ -44,10 +63,10 @@ class StatusCode:
         :param message: 替换的消息内容
         :return:
         """
-        return "A0310", "请求缺少必要参数:{}".format(message)
+        return "A0320", "请求缺少必要参数:{}".format(message)
 
-    INVALID_TIME_STAMP = ("A0311", "非法的时间戳参数")
-    USER_INPUT_INVALID = ("A0312", "用户输入内容非法")
+    INVALID_TIME_STAMP = ("A0321", "非法的时间戳参数")
+    USER_INPUT_INVALID = ("A0322", "用户输入内容非法")
     VALIDATE_CODE_EXPIRE = ("A0400", "验证码过期")
     FORM_VALIDATE_FAIL = ("A0401", "表单校验失败")
     PARAM_VALIDATE_FAIL = ("A0402", "参数校验失败")
@@ -69,6 +88,7 @@ class StatusCode:
     RESOURCE_DISABLED = ("B0002", "资源被禁用")
     RESOURCE_NO_AUTHORITY = ("B0003", "该资源未定义访问权限")
     RESOURCE_NOT_FOUND = ("B0404", "访问资源不存在")
+
     # INTERNAL_SERVER_ERROR = ("B0500", "服务器内部错误:{}")
 
     @staticmethod
@@ -89,9 +109,9 @@ class StatusCode:
         :return:
         """
         return "B0501", "{}已存在,确保唯一性，不可重复".format(message)
+
     TIMEOUT = ("B0100", "系统执行超时")
     STRIKE_RECOVERY = ("B0200", "系统容灾系统被触发")
     RPC_INVOKE_ERROR = ("C0001", "调用第三方服务出错")
     SERVER_ERROR = ("C0002", "服务器内部错误")
     UNKNOWN_ERROR = ("C0003", "未知异常")
-
